@@ -5,19 +5,12 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/stretchr/testify/require"
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/engine/ahocorasick"
 )
 
-var (
-	invalidPattern = `
-	azure:
-		url: http://invalid.azurecr.io.azure.com
-		secret: BXIMbhBlC3=5hIbqCEKvq7op!V2ZfO0XWbcnasZmPm/AJfQqdcnt/+2Ytxc1hDq1m/
-	`
-)
-
 func TestAzureContainerRegistry_Pattern(t *testing.T) {
 	d := Scanner{}
 	ahoCorasickCore := ahocorasick.NewAhoCorasickCore([]detectors.Detector{d})
@@ -30,28 +23,27 @@ func TestAzureContainerRegistry_Pattern(t *testing.T) {
 		{
 			name: "pwd",
 			input: `source storage.env
-
-ACR=smpldev.azurecr.io
-ACRUSER=smpldev
-ACRPWD=Cw8xeDNK6Bub3p61aq5ij/TiVvtBicpTj5rverVezj+ACRBPkEcx
-CONTAINER=storage-svc:latest`,
+				ACR=smpldev.azurecr.io
+				ACRUSER=smpldev
+				ACRPWD=Cw8xeDNK6Bub3p61aq5ij/TiVvtBicpTj5rverVezj+ACRBPkEcx
+				CONTAINER=storage-svc:latest`,
 			want: []string{`{"username":"smpldev","password":"Cw8xeDNK6Bub3p61aq5ij/TiVvtBicpTj5rverVezj+ACRBPkEcx"}`},
 		},
 		{
 			name: "password",
 			input: `    - name: Deploy to ARC
-      uses: azure/docker-login@v1
-      with:
-            login-server: crmshopacr.azurecr.io
-            username: crmshopacr
-            password: o9uXSjWlUdRwAeGP2xGSfGy+25vetsONo3Mq13fksa+ACRBXyFsY
-    - run: |`,
+						uses: azure/docker-login@v1
+						with:
+								login-server: crmshopacr.azurecr.io
+								username: crmshopacr
+								password: o9uXSjWlUdRwAeGP2xGSfGy+25vetsONo3Mq13fksa+ACRBXyFsY
+						- run: |`,
 			want: []string{`{"username":"crmshopacr","password":"o9uXSjWlUdRwAeGP2xGSfGy+25vetsONo3Mq13fksa+ACRBXyFsY"}`},
 		},
 		{
 			name: "docker cli login",
 			input: `docker login dvacr00.azurecr.io -u dvacr00 -p Ljc+1lq0U0+c3jHlMHxSxAhCipKt6zU43HfMle/Ymj+ACRAKcPHy
-docker push dvacr00.azurecr.io/foo-alpine:3.18`,
+					docker push dvacr00.azurecr.io/foo-alpine:3.18`,
 			want: []string{`{"username":"dvacr00","password":"Ljc+1lq0U0+c3jHlMHxSxAhCipKt6zU43HfMle/Ymj+ACRAKcPHy"}`},
 		},
 		{
@@ -62,16 +54,15 @@ docker push dvacr00.azurecr.io/foo-alpine:3.18`,
 		{
 			name: "README",
 			input: `# AZURE-CICD-Deployment-with-Github-Actions
+					## Save pass:
 
-## Save pass:
-
-s3cEZKH3yytiVnJ3h+eI3qhhzf9l1vNwEi1+q+WGdd+ACRCZ7JD6
+					s3cEZKH3yytiVnJ3h+eI3qhhzf9l1vNwEi1+q+WGdd+ACRCZ7JD6
 
 
-## Run from terminal:
+					## Run from terminal:
 
-docker build -t testapp.azurecr.io/chicken:latest .
-`,
+					docker build -t testapp.azurecr.io/chicken:latest .
+					`,
 			want: []string{`{"username":"testapp","password":"s3cEZKH3yytiVnJ3h+eI3qhhzf9l1vNwEi1+q+WGdd+ACRCZ7JD6"}`},
 		},
 		// TODO:
@@ -85,9 +76,13 @@ docker build -t testapp.azurecr.io/chicken:latest .
 		//	input: ``,
 		//	want:  []string{},
 		{
-			name:  "invalid pattern",
-			input: invalidPattern,
-			want:  nil,
+			name: "invalid pattern",
+			input: `
+				azure:
+					url: http://invalid.azurecr.io.azure.com
+					secret: BXIMbhBlC3=5hIbqCEKvq7op!V2ZfO0XWbcnasZmPm/AJfQqdcnt/+2Ytxc1hDq1m/
+				`,
+			want: nil,
 		},
 	}
 
@@ -95,22 +90,15 @@ docker build -t testapp.azurecr.io/chicken:latest .
 		t.Run(test.name, func(t *testing.T) {
 			matchedDetectors := ahoCorasickCore.FindDetectorMatches([]byte(test.input))
 			if len(matchedDetectors) == 0 {
-				t.Errorf("keywords '%v' not matched by: %s", d.Keywords(), test.input)
+				t.Errorf("test %q failed: expected keywords %v to be found in the input", test.name, d.Keywords())
 				return
 			}
 
 			results, err := d.FromData(context.Background(), false, []byte(test.input))
-			if err != nil {
-				t.Errorf("error = %v", err)
-				return
-			}
+			require.NoError(t, err)
 
 			if len(results) != len(test.want) {
-				if len(results) == 0 {
-					t.Errorf("did not receive result")
-				} else {
-					t.Errorf("expected %d results, only received %d", len(test.want), len(results))
-				}
+				t.Errorf("mismatch in result count: expected %d, got %d", len(test.want), len(results))
 				return
 			}
 
@@ -122,6 +110,7 @@ docker build -t testapp.azurecr.io/chicken:latest .
 					actual[string(r.Raw)] = struct{}{}
 				}
 			}
+
 			expected := make(map[string]struct{}, len(test.want))
 			for _, v := range test.want {
 				expected[v] = struct{}{}
