@@ -42,14 +42,8 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	uriMatches := uriPat.FindAllStringSubmatch(dataStr, -1)
 
 	for _, match := range matches {
-		if len(match) != 2 {
-			continue
-		}
 		resMatch := strings.TrimSpace(match[1])
 		for _, uriMatch := range uriMatches {
-			if len(uriMatch) != 2 {
-				continue
-			}
 			resURI := strings.TrimSpace(uriMatch[1])
 
 			s1 := detectors.Result{
