@@ -1,6 +1,9 @@
 package sources
 
 import (
+	"encoding/json"
+	"errors"
+	"runtime"
 	"sync"
 
 	"google.golang.org/protobuf/types/known/anypb"
@@ -65,7 +68,7 @@ type Source interface {
 	SourceID() SourceID
 	// JobID returns the initialized job ID used for tracking relationships in the DB.
 	JobID() JobID
-	// Init initializes the source.
+	// Init initializes the source. Calling this method more than once is undefined behavior.
 	Init(aCtx context.Context, name string, jobId JobID, sourceId SourceID, verify bool, connection *anypb.Any, concurrency int) error
 	// Chunks emits data over a channel which is then decoded and scanned for secrets.
 	// By default, data is obtained indiscriminately. However, by providing one or more
@@ -103,6 +106,56 @@ type SourceUnitEnumerator interface {
 	Enumerate(ctx context.Context, reporter UnitReporter) error
 }
 
+// ConfiguredSource is a Source with most of its initialization values
+// pre-configured from a [sourcespb.LocalSource] configuration struct. It
+// exposes a simplified Init() method and can be only initialized once. This
+// struct is not necessary for running sources, but it helps simplify gathering
+// all of the necessary information to call the [Source.Init] method.
+type ConfiguredSource struct {
+	Name       string
+	source     Source
+	initParams struct {
+		verify      bool
+		conn        *anypb.Any
+		concurrency int
+	}
+}
+
+// NewConfiguredSource pre-configures an instantiated Source object with the
+// provided protobuf configuration.
+func NewConfiguredSource(s Source, config *sourcespb.LocalSource) ConfiguredSource {
+	return ConfiguredSource{
+		Name:   config.GetName(),
+		source: s,
+		initParams: struct {
+			verify      bool
+			conn        *anypb.Any
+			concurrency int
+		}{
+			verify:      config.GetVerify(),
+			conn:        config.GetConnection(),
+			concurrency: runtime.NumCPU(),
+		},
+	}
+}
+
+// SourceType exposes the underlying source type.
+func (c *ConfiguredSource) SourceType() sourcespb.SourceType {
+	return c.source.Type()
+}
+
+// Init returns the initialized Source. The ConfiguredSource is unusable after
+// calling this method because initializing a [Source] more than once is undefined.
+func (c *ConfiguredSource) Init(ctx context.Context, sourceID SourceID, jobID JobID) (Source, error) {
+	if c.source == nil {
+		return nil, errors.New("source already initialized")
+	}
+	src := c.source
+	err := src.Init(ctx, c.Name, jobID, sourceID, c.initParams.verify, c.initParams.conn, c.initParams.concurrency)
+	c.source = nil
+	return src, err
+}
+
 // BaseUnitReporter is a helper struct that implements the UnitReporter interface
 // and includes a JobProgress reference.
 type baseUnitReporter struct {
@@ -175,6 +228,8 @@ type DockerConfig struct {
 	BearerToken string
 	// UseDockerKeychain determines whether to use the Docker keychain.
 	UseDockerKeychain bool
+	// ExcludePaths is a list of paths to exclude from scanning.
+	ExcludePaths []string
 }
 
 // GCSConfig defines the optional configuration for a GCS source.
@@ -261,6 +316,8 @@ type GithubConfig struct {
 	IncludeWikis bool
 	// CommentsTimeframeDays indicates how many days of comments to include in the scan.
 	CommentsTimeframeDays uint32
+	// AuthInUrl determines wether to use authentication token in repository url or in header.
+	AuthInUrl bool
 }
 
 // GitHubExperimentalConfig defines the optional configuration for an experimental GitHub source.
@@ -285,6 +342,8 @@ type GitlabConfig struct {
 	Token string
 	// Repos is the list of repositories to scan.
 	Repos []string
+	// GroupIds is the list of groups to scan.
+	GroupIds []string
 	// Filter is the filter to use to scan the source.
 	Filter *common.Filter
 	// SkipBinaries allows skipping binary files from the scan.
@@ -293,6 +352,8 @@ type GitlabConfig struct {
 	IncludeRepos []string
 	// ExcludeRepos is a list of repositories to exclude from the scan.
 	ExcludeRepos []string
+	// AuthInUrl determines wether to use authentication token in repository url or in header.
+	AuthInUrl bool
 }
 
 // FilesystemConfig defines the optional configuration for a filesystem source.
@@ -385,14 +446,18 @@ type ElasticsearchConfig struct {
 	BestEffortScan bool
 }
 
+type StdinConfig struct{}
+
 // Progress is used to update job completion progress across sources.
 type Progress struct {
-	mut               sync.Mutex
-	PercentComplete   int64
-	Message           string
-	EncodedResumeInfo string
-	SectionsCompleted int32
-	SectionsRemaining int32
+	mut sync.Mutex
+	// encodedResumeInfoByID is used for sub-unit resumption (see below)
+	encodedResumeInfoByID map[string]string
+	PercentComplete       int64
+	Message               string
+	EncodedResumeInfo     string
+	SectionsCompleted     int32
+	SectionsRemaining     int32
 }
 
 // Validator is an interface for validating a source. Sources can optionally implement this interface to validate
@@ -450,3 +515,71 @@ func (p *Progress) GetProgress() *Progress {
 	defer p.mut.Unlock()
 	return p
 }
+
+// -sub-unit-resumption------------------------------------------------------------
+//
+// The following collection of methods are intended to provide a thread-safe
+// way to access the EncodedResumeInfo for Sources to enable saving and
+// resuming progress mid SourceUnit scan.
+//
+// This level of synchronization is only necessary when multiple concurrent
+// invocations of ChunkUnit consume/mutate the same Progress object. The source
+// manager executes scans this way under certain circumstances.
+//
+// Usage:
+//  - id should be the SourceUnit ID
+//  - value is opaque data each Source uses
+//
+
+// GetEncodedResumeInfoFor gets the encoded resume information for the provided
+// ID, usually a unit ID.
+func (p *Progress) GetEncodedResumeInfoFor(id string) string {
+	p.mut.Lock()
+	defer p.mut.Unlock()
+	p.ensureEncodedResumeInfoByID()
+	return p.encodedResumeInfoByID[id]
+}
+
+// SetEncodedResumeInfoFor sets the encoded resume information for the provided
+// ID, usually a unit ID.
+func (p *Progress) SetEncodedResumeInfoFor(id, value string) {
+	p.mut.Lock()
+	defer p.mut.Unlock()
+	p.ensureEncodedResumeInfoByID()
+	p.encodedResumeInfoByID[id] = value
+	p.EncodedResumeInfo = marshalEncodedResumeInfo(p.encodedResumeInfoByID)
+}
+
+// ClearEncodedResumeInfoFor removes the encoded resume information from being
+// tracked.
+func (p *Progress) ClearEncodedResumeInfoFor(id string) {
+	p.mut.Lock()
+	defer p.mut.Unlock()
+	p.ensureEncodedResumeInfoByID()
+	delete(p.encodedResumeInfoByID, id)
+	p.EncodedResumeInfo = marshalEncodedResumeInfo(p.encodedResumeInfoByID)
+}
+
+// ensureEncodedResumeInfoByID ensures the encodedResumeInfoByID attribute is a
+// non-nil map. The mutex must be held when calling this function.
+func (p *Progress) ensureEncodedResumeInfoByID() {
+	if p.encodedResumeInfoByID != nil {
+		return
+	}
+	p.encodedResumeInfoByID = unmarshalEncodedResumeInfo(p.EncodedResumeInfo)
+}
+
+// marshalEncodedResumeInfo converts a map of values into a serialized string.
+func marshalEncodedResumeInfo(values map[string]string) string {
+	marshalled, _ := json.Marshal(values)
+	return string(marshalled)
+}
+
+// unmarshalEncodedResumeInfo converts a serialized string into a map of values.
+func unmarshalEncodedResumeInfo(data string) map[string]string {
+	resumeInfo := make(map[string]string)
+	_ = json.Unmarshal([]byte(data), &resumeInfo)
+	return resumeInfo
+}
+
+// -/sub-unit-resumption-----------------------------------------------------------
