@@ -19,7 +19,7 @@ func GetFields() githubCmdModel {
 	org := textinputs.InputConfig{
 		Label:       "Organization",
 		Key:         "org",
-		Required:    false,
+		Required:    true,
 		Help:        "GitHub organization to scan.",
 		Placeholder: "trufflesecurity",
 	}
@@ -27,7 +27,7 @@ func GetFields() githubCmdModel {
 	repo := textinputs.InputConfig{
 		Label:       "Repository",
 		Key:         "repo",
-		Required:    false,
+		Required:    true,
 		Help:        "GitHub repo to scan.",
 		Placeholder: "https://github.com/trufflesecurity/test_keys",
 	}
@@ -35,25 +35,39 @@ func GetFields() githubCmdModel {
 	return githubCmdModel{textinputs.New([]textinputs.InputConfig{org, repo})}
 }
 
+// Handle default values since GitHub flags are OR operations
+func (m githubCmdModel) GetSpecialInputs() map[string]textinputs.Input {
+	inputs := m.GetInputs()
+	if inputs["org"].IsDefault != inputs["repo"].IsDefault {
+		if inputs["org"].IsDefault {
+			delete(inputs, "org")
+		}
+		if inputs["repo"].IsDefault {
+			delete(inputs, "repo")
+		}
+	}
+
+	return inputs
+}
+
 func (m githubCmdModel) Cmd() string {
 	var command []string
 	command = append(command, "trufflehog", "github")
+	inputs := m.GetSpecialInputs()
 
-	inputs := m.GetInputs()
-
-	if inputs["org"] != "" {
-		command = append(command, "--org="+inputs["org"])
+	if inputs["org"].Value != "" {
+		command = append(command, "--org="+inputs["org"].Value)
 	}
 
-	if inputs["repo"] != "" {
-		command = append(command, "--repo="+inputs["repo"])
+	if inputs["repo"].Value != "" {
+		command = append(command, "--repo="+inputs["repo"].Value)
 	}
 
 	return strings.Join(command, " ")
 }
 
 func (m githubCmdModel) Summary() string {
-	inputs := m.GetInputs()
+	inputs := m.GetSpecialInputs()
 	labels := m.GetLabels()
 
 	keys := []string{"org", "repo"}
